Kreveik 
=======

_boolfuncs_ - houses functions that are going to act implicitly on network objects only, 
making them take a step due to the dynamic of the function. 

_classes_ - houses the class definitions of the project, mainly networks and families.

_family_ this is the module that has functions that will implicitly act on objects of 
kind family. This includes functions that are of type 

_genetic_ this module has the bits and pieces of the genetic algorithm. 
It will have the core engine, definitions of the mutator, killer, 
